==> cvstrac-1.1.0.tar.gz: cvstrac-1.1.0/image.c <==
/*
** Copyright (c) 2002 D. Richard Hipp
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public
** License as published by the Free Software Foundation; either
** version 2 of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** General Public License for more details.
** 
** You should have received a copy of the GNU General Public
** License along with this library; if not, write to the
** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
** Boston, MA  02111-1307, USA.
**
** Author contact information:
**   drh@hwaci.com
**   http://www.hwaci.com/drh/
**
*******************************************************************************
**
** This file contains the encoded GIF images used by CVSTrac
*/
#include "image.h"

static const char zCkImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x37, 0x61, 0x09, 0x00,
 0x09, 0x00, 0xf0, 0x00, 0x00, 0xff, 0xff, 0xff,
 0x00, 0x96, 0x00, 0x2c, 0x00, 0x00, 0x00, 0x00,
 0x09, 0x00, 0x09, 0x00, 0x00, 0x02, 0x11, 0x84,
 0x8f, 0x09, 0x11, 0xca, 0x8d, 0xde, 0x3a, 0x72,
 0x41, 0x46, 0x1f, 0xce, 0x3b, 0xc2, 0x53, 0x00,
 0x00, 0x3b
};

static const char zDotImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x37, 0x61, 0x09, 0x00,
 0x09, 0x00, 0xf3, 0x00, 0x00, 0x00, 0x00, 0xff,
 0x1f, 0x1f, 0xff, 0x2f, 0x2f, 0xff, 0x4f, 0x4f,
 0xff, 0x7f, 0x7f, 0xff, 0x8f, 0x8f, 0xff, 0xbf,
 0xbf, 0xff, 0xdf, 0xdf, 0xff, 0xe4, 0xe2, 0xe2,
 0xef, 0xef, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00,
 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 0x00, 0x00, 0x00, 0x00, 0x00, 0x2c, 0x00, 0x00,
 0x00, 0x00, 0x09, 0x00, 0x09, 0x00, 0x00, 0x04,
 0x1c, 0x50, 0xc9, 0x49, 0xe7, 0x31, 0x35, 0x0d,
 0x00, 0x08, 0xdd, 0x1c, 0x50, 0x48, 0x47, 0xc8,
 0x05, 0x92, 0x61, 0x72, 0x13, 0x61, 0x62, 0x53,
 0x11, 0x00, 0x70, 0x45, 0x45, 0x00, 0x3b
};

static const char zXImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x37, 0x61, 0x09, 0x00,
 0x09, 0x00, 0xf0, 0x00, 0x00, 0xff, 0xff, 0xff,
 0xff, 0x00, 0x00, 0x2c, 0x00, 0x00, 0x00, 0x00,
 0x09, 0x00, 0x09, 0x00, 0x00, 0x02, 0x11, 0x4c,
 0x80, 0x68, 0x9b, 0xec, 0xd6, 0xd6, 0x49, 0x80,
 0x51, 0x39, 0x2b, 0x7c, 0x19, 0x53, 0x5d, 0x00,
 0x00, 0x3b
};

static const char zDiaImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x09, 0x00,
 0x09, 0x00, 0xf0, 0x00, 0x00, 0xff, 0xff, 0xff,
 0xfd, 0x9f, 0x00, 0x21, 0xf9, 0x04, 0x01, 0x00,
 0x00, 0x00, 0x00, 0x2c, 0x00, 0x00, 0x00, 0x00,
 0x09, 0x00, 0x09, 0x00, 0x00, 0x02, 0x11, 0x84,
 0x11, 0xa7, 0xc1, 0x8a, 0xdc, 0x0c, 0x9c, 0x6f,
 0xc2, 0x4a, 0x65, 0x3e, 0xd7, 0x21, 0x55, 0x00,
 0x00, 0x3b
};

static const char zBackupImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x14, 0x00,
 0x16, 0x00, 0xc2, 0x00, 0x00, 0xff, 0xff, 0xff,
 0xcc, 0xff, 0xff, 0x99, 0x99, 0x99, 0x66, 0x66,
 0x66, 0x33, 0x33, 0x33, 0x00, 0x00, 0x00, 0x00,
 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0xfe, 0x4e,
 0x54, 0x68, 0x69, 0x73, 0x20, 0x61, 0x72, 0x74,
 0x20, 0x69, 0x73, 0x20, 0x69, 0x6e, 0x20, 0x74,
 0x68, 0x65, 0x20, 0x70, 0x75, 0x62, 0x6c, 0x69,
 0x63, 0x20, 0x64, 0x6f, 0x6d, 0x61, 0x69, 0x6e,
 0x2e, 0x20, 0x4b, 0x65, 0x76, 0x69, 0x6e, 0x20,
 0x48, 0x75, 0x67, 0x68, 0x65, 0x73, 0x2c, 0x20,
 0x6b, 0x65, 0x76, 0x69, 0x6e, 0x68, 0x40, 0x65,
 0x69, 0x74, 0x2e, 0x63, 0x6f, 0x6d, 0x2c, 0x20,
 0x53, 0x65, 0x70, 0x74, 0x65, 0x6d, 0x62, 0x65,
 0x72, 0x20, 0x31, 0x39, 0x39, 0x35, 0x00, 0x21,
 0xf9, 0x04, 0x01, 0x00, 0x00, 0x01, 0x00, 0x2c,
 0x00, 0x00, 0x00, 0x00, 0x14, 0x00, 0x16, 0x00,
 0x00, 0x03, 0x4b, 0x18, 0xba, 0xdc, 0xfe, 0x23,
 0x10, 0xf2, 0x6a, 0x10, 0x33, 0x53, 0xbb, 0xa2,
 0xce, 0xdc, 0xf5, 0x69, 0x9c, 0x37, 0x4e, 0x16,
 0x76, 0x82, 0x90, 0x74, 0x06, 0x05, 0x37, 0x2a,
 0x45, 0x1c, 0x6e, 0x58, 0x6d, 0x2f, 0xfb, 0x92,
 0xeb, 0x35, 0x46, 0x50, 0xf1, 0x03, 0xea, 0x78,
 0xc6, 0xa4, 0x91, 0xa6, 0x6c, 0x16, 0x28, 0x4e,
 0xa7, 0x20, 0xda, 0x8c, 0xc0, 0xa8, 0x3a, 0x82,
 0x40, 0x18, 0xd5, 0x56, 0x92, 0xde, 0xd0, 0x55,
 0xfc, 0xe8, 0x91, 0xcf, 0x8b, 0x04, 0x00, 0x3b,
};

static const char zDirImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x14, 0x00,
 0x16, 0x00, 0xc2, 0x00, 0x00, 0xff, 0xff, 0xff,
 0xff, 0xcc, 0x99, 0xcc, 0xff, 0xff, 0x99, 0x66,
 0x33, 0x33, 0x33, 0x33, 0x00, 0x00, 0x00, 0x00,
 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0xfe, 0x4e,
 0x54, 0x68, 0x69, 0x73, 0x20, 0x61, 0x72, 0x74,
 0x20, 0x69, 0x73, 0x20, 0x69, 0x6e, 0x20, 0x74,
 0x68, 0x65, 0x20, 0x70, 0x75, 0x62, 0x6c, 0x69,
 0x63, 0x20, 0x64, 0x6f, 0x6d, 0x61, 0x69, 0x6e,
 0x2e, 0x20, 0x4b, 0x65, 0x76, 0x69, 0x6e, 0x20,
 0x48, 0x75, 0x67, 0x68, 0x65, 0x73, 0x2c, 0x20,
 0x6b, 0x65, 0x76, 0x69, 0x6e, 0x68, 0x40, 0x65,
 0x69, 0x74, 0x2e, 0x63, 0x6f, 0x6d, 0x2c, 0x20,
 0x53, 0x65, 0x70, 0x74, 0x65, 0x6d, 0x62, 0x65,
 0x72, 0x20, 0x31, 0x39, 0x39, 0x35, 0x00, 0x21,
 0xf9, 0x04, 0x01, 0x00, 0x00, 0x02, 0x00, 0x2c,
 0x00, 0x00, 0x00, 0x00, 0x14, 0x00, 0x16, 0x00,
 0x00, 0x03, 0x54, 0x28, 0xba, 0xdc, 0xfe, 0x30,
 0xca, 0x49, 0x59, 0xb9, 0xf8, 0xce, 0x12, 0xba,
 0xef, 0x45, 0xc4, 0x7d, 0x64, 0xa6, 0x29, 0xc5,
 0x40, 0x7a, 0x6a, 0x89, 0x06, 0x43, 0x2c, 0xc7,
 0x2b, 0x1c, 0x8e, 0xf5, 0x1a, 0x13, 0x57, 0x9e,
 0x0f, 0x3c, 0x9c, 0x8f, 0x05, 0xec, 0x0d, 0x49,
 0x45, 0xe1, 0x71, 0x67, 0x3c, 0xb2, 0x82, 0x4e,
 0x22, 0x34, 0xda, 0x49, 0x52, 0x61, 0x56, 0x98,
 0x56, 0xc5, 0xdd, 0xc2, 0x78, 0x82, 0xd4, 0x6c,
 0x3c, 0x26, 0x80, 0xc3, 0xe6, 0xb4, 0x7a, 0xcd,
 0x23, 0x2c, 0x4c, 0xf0, 0x8c, 0x3b, 0x01, 0x00,
 0x3b,
};

static const char zFileImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x14, 0x00,
 0x16, 0x00, 0xc2, 0x00, 0x00, 0xff, 0xff, 0xff,
 0xcc, 0xff, 0xff, 0x99, 0x99, 0x99, 0x33, 0x33,
 0x33, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0xfe, 0x4e,
 0x54, 0x68, 0x69, 0x73, 0x20, 0x61, 0x72, 0x74,
 0x20, 0x69, 0x73, 0x20, 0x69, 0x6e, 0x20, 0x74,
 0x68, 0x65, 0x20, 0x70, 0x75, 0x62, 0x6c, 0x69,
 0x63, 0x20, 0x64, 0x6f, 0x6d, 0x61, 0x69, 0x6e,
 0x2e, 0x20, 0x4b, 0x65, 0x76, 0x69, 0x6e, 0x20,
 0x48, 0x75, 0x67, 0x68, 0x65, 0x73, 0x2c, 0x20,
 0x6b, 0x65, 0x76, 0x69, 0x6e, 0x68, 0x40, 0x65,
 0x69, 0x74, 0x2e, 0x63, 0x6f, 0x6d, 0x2c, 0x20,
 0x53, 0x65, 0x70, 0x74, 0x65, 0x6d, 0x62, 0x65,
 0x72, 0x20, 0x31, 0x39, 0x39, 0x35, 0x00, 0x21,
 0xf9, 0x04, 0x01, 0x00, 0x00, 0x01, 0x00, 0x2c,
 0x00, 0x00, 0x00, 0x00, 0x14, 0x00, 0x16, 0x00,
 0x00, 0x03, 0x58, 0x38, 0xba, 0xbc, 0xf1, 0x30,
 0x0c, 0x40, 0xab, 0x9d, 0x23, 0xbe, 0x69, 0x3b,
 0xcf, 0x11, 0xd7, 0x55, 0x22, 0xb8, 0x8d, 0xd7,
 0x05, 0x71, 0x44, 0xeb, 0x52, 0xc4, 0x10, 0xcf,
 0x27, 0x0a, 0xbb, 0x6e, 0x8d, 0xb7, 0x96, 0xe0,
 0x0b, 0x84, 0x9a, 0xad, 0xf2, 0x0b, 0x4a, 0x6e,
 0xbb, 0x17, 0x05, 0x28, 0x1c, 0x12, 0x8d, 0xac,
 0xa4, 0x12, 0xc0, 0x3c, 0x3a, 0x7b, 0x50, 0xa4,
 0xf4, 0xd9, 0xbc, 0x56, 0x45, 0xda, 0xe9, 0xf7,
 0x8a, 0xed, 0x6e, 0x97, 0x59, 0x32, 0xba, 0xeb,
 0xfc, 0x0e, 0x7e, 0xf0, 0xb8, 0x4f, 0x16, 0x91,
 0xda, 0x8d, 0x09, 0x00, 0x3b,
};

/*
** WEBPAGE: /ck.gif
*/
void image_ck(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zCkImage, sizeof(zCkImage));
  g.isConst = 1;
}

/*
** WEBPAGE: /dot.gif
*/
void image_dot(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zDotImage, sizeof(zDotImage));
  g.isConst = 1;
}

/*
** WEBPAGE: /x.gif
*/
void image_x(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zXImage, sizeof(zXImage));
  g.isConst = 1;
}

/*
** WEBPAGE: /dia.gif
*/
void image_dia(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zDiaImage, sizeof(zDiaImage));
  g.isConst = 1;
}

/*
** WEBPAGE: /backup.gif
*/
void image_backup(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zBackupImage, sizeof(zBackupImage));
  g.isConst = 1;
}
/*
** WEBPAGE: /dir.gif
*/
void image_dir(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zDirImage, sizeof(zDirImage));
  g.isConst = 1;
}
/*
** WEBPAGE: /file.gif
*/
void image_file(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zFileImage, sizeof(zFileImage));
  g.isConst = 1;
}

==> cvstrac-1.1.1.tar.gz: cvstrac-1.1.1/image.c <==
/*
** Copyright (c) 2002 D. Richard Hipp
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public
** License as published by the Free Software Foundation; either
** version 2 of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** General Public License for more details.
** 
** You should have received a copy of the GNU General Public
** License along with this library; if not, write to the
** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
** Boston, MA  02111-1307, USA.
**
** Author contact information:
**   drh@hwaci.com
**   http://www.hwaci.com/drh/
**
*******************************************************************************
**
** This file contains the encoded GIF images used by CVSTrac
*/
#include "image.h"

static const char zCkImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x09, 0x00,
 0x09, 0x00, 0xc2, 0x00, 0x00, 0xff, 0xff, 0xff,
 0xff, 0x00, 0x00, 0xff, 0x99, 0x00, 0x00, 0x00,
 0xff, 0x00, 0x99, 0x00, 0xff, 0xff, 0xff, 0xff,
 0xff, 0xff, 0xff, 0xff, 0xff, 0x21, 0xf9, 0x04,
 0x01, 0x0a, 0x00, 0x07, 0x00, 0x2c, 0x00, 0x00,
 0x00, 0x00, 0x09, 0x00, 0x09, 0x00, 0x00, 0x03,
 0x12, 0x78, 0xba, 0x4a, 0xbc, 0xc4, 0xbd, 0x28,
 0x61, 0x3c, 0x95, 0x36, 0xa7, 0x77, 0xb7, 0x15,
 0x13, 0x2a, 0x09, 0x00, 0x3b
};

static const char zDotImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x09, 0x00,
 0x09, 0x00, 0xc2, 0x00, 0x00, 0xff, 0xff, 0xff,
 0xff, 0x00, 0x00, 0xff, 0x99, 0x00, 0x00, 0x00,
 0xff, 0x00, 0x99, 0x00, 0xff, 0xff, 0xff, 0xff,
 0xff, 0xff, 0xff, 0xff, 0xff, 0x21, 0xf9, 0x04,
 0x01, 0x0a, 0x00, 0x07, 0x00, 0x2c, 0x00, 0x00,
 0x00, 0x00, 0x09, 0x00, 0x09, 0x00, 0x00, 0x03,
 0x11, 0x78, 0xba, 0xac, 0xf3, 0xed, 0xc9, 0x25,
 0xab, 0xab, 0xf0, 0xe0, 0xac, 0x2d, 0x9b, 0x4d,
 0x98, 0x00, 0x00, 0x3b
};

static const char zXImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x09, 0x00,
 0x09, 0x00, 0xc2, 0x00, 0x00, 0xff, 0xff, 0xff,
 0xff, 0x00, 0x00, 0xff, 0x99, 0x00, 0x00, 0x00,
 0xff, 0x00, 0x99, 0x00, 0xff, 0xff, 0xff, 0xff,
 0xff, 0xff, 0xff, 0xff, 0xff, 0x21, 0xf9, 0x04,
 0x01, 0x0a, 0x00, 0x07, 0x00, 0x2c, 0x00, 0x00,
 0x00, 0x00, 0x09, 0x00, 0x09, 0x00, 0x00, 0x03,
 0x12, 0x18, 0x71, 0xcc, 0xfa, 0x0d, 0x4a, 0x15,
 0xdf, 0x6a, 0x07, 0x62, 0x7b, 0x33, 0x9d, 0x1d,
 0x87, 0x79, 0x09, 0x00, 0x3b
};

static const char zDiaImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x09, 0x00,
 0x09, 0x00, 0xc2, 0x00, 0x00, 0xff, 0xff, 0xff,
 0xff, 0x00, 0x00, 0xff, 0x99, 0x00, 0x00, 0x00,
 0xff, 0x00, 0x99, 0x00, 0xff, 0xff, 0xff, 0xff,
 0xff, 0xff, 0xff, 0xff, 0xff, 0x21, 0xf9, 0x04,
 0x01, 0x0a, 0x00, 0x07, 0x00, 0x2c, 0x00, 0x00,
 0x00, 0x00, 0x09, 0x00, 0x09, 0x00, 0x00, 0x03,
 0x12, 0x78, 0x7a, 0xb2, 0x2e, 0xd0, 0x31, 0x18,
 0x15, 0xbd, 0xf3, 0xd2, 0x8c, 0x6d, 0x5f, 0x9b,
 0xc4, 0x38, 0x09, 0x00, 0x3b
};

static const char zBackupImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x14, 0x00,
 0x16, 0x00, 0xc2, 0x00, 0x00, 0xff, 0xff, 0xff,
 0xcc, 0xff, 0xff, 0x99, 0x99, 0x99, 0x66, 0x66,
 0x66, 0x33, 0x33, 0x33, 0x00, 0x00, 0x00, 0x00,
 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0xfe, 0x4e,
 0x54, 0x68, 0x69, 0x73, 0x20, 0x61, 0x72, 0x74,
 0x20, 0x69, 0x73, 0x20, 0x69, 0x6e, 0x20, 0x74,
 0x68, 0x65, 0x20, 0x70, 0x75, 0x62, 0x6c, 0x69,
 0x63, 0x20, 0x64, 0x6f, 0x6d, 0x61, 0x69, 0x6e,
 0x2e, 0x20, 0x4b, 0x65, 0x76, 0x69, 0x6e, 0x20,
 0x48, 0x75, 0x67, 0x68, 0x65, 0x73, 0x2c, 0x20,
 0x6b, 0x65, 0x76, 0x69, 0x6e, 0x68, 0x40, 0x65,
 0x69, 0x74, 0x2e, 0x63, 0x6f, 0x6d, 0x2c, 0x20,
 0x53, 0x65, 0x70, 0x74, 0x65, 0x6d, 0x62, 0x65,
 0x72, 0x20, 0x31, 0x39, 0x39, 0x35, 0x00, 0x21,
 0xf9, 0x04, 0x01, 0x00, 0x00, 0x01, 0x00, 0x2c,
 0x00, 0x00, 0x00, 0x00, 0x14, 0x00, 0x16, 0x00,
 0x00, 0x03, 0x4b, 0x18, 0xba, 0xdc, 0xfe, 0x23,
 0x10, 0xf2, 0x6a, 0x10, 0x33, 0x53, 0xbb, 0xa2,
 0xce, 0xdc, 0xf5, 0x69, 0x9c, 0x37, 0x4e, 0x16,
 0x76, 0x82, 0x90, 0x74, 0x06, 0x05, 0x37, 0x2a,
 0x45, 0x1c, 0x6e, 0x58, 0x6d, 0x2f, 0xfb, 0x92,
 0xeb, 0x35, 0x46, 0x50, 0xf1, 0x03, 0xea, 0x78,
 0xc6, 0xa4, 0x91, 0xa6, 0x6c, 0x16, 0x28, 0x4e,
 0xa7, 0x20, 0xda, 0x8c, 0xc0, 0xa8, 0x3a, 0x82,
 0x40, 0x18, 0xd5, 0x56, 0x92, 0xde, 0xd0, 0x55,
 0xfc, 0xe8, 0x91, 0xcf, 0x8b, 0x04, 0x00, 0x3b,
};

static const char zDirImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x14, 0x00,
 0x16, 0x00, 0xc2, 0x00, 0x00, 0xff, 0xff, 0xff,
 0xff, 0xcc, 0x99, 0xcc, 0xff, 0xff, 0x99, 0x66,
 0x33, 0x33, 0x33, 0x33, 0x00, 0x00, 0x00, 0x00,
 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0xfe, 0x4e,
 0x54, 0x68, 0x69, 0x73, 0x20, 0x61, 0x72, 0x74,
 0x20, 0x69, 0x73, 0x20, 0x69, 0x6e, 0x20, 0x74,
 0x68, 0x65, 0x20, 0x70, 0x75, 0x62, 0x6c, 0x69,
 0x63, 0x20, 0x64, 0x6f, 0x6d, 0x61, 0x69, 0x6e,
 0x2e, 0x20, 0x4b, 0x65, 0x76, 0x69, 0x6e, 0x20,
 0x48, 0x75, 0x67, 0x68, 0x65, 0x73, 0x2c, 0x20,
 0x6b, 0x65, 0x76, 0x69, 0x6e, 0x68, 0x40, 0x65,
 0x69, 0x74, 0x2e, 0x63, 0x6f, 0x6d, 0x2c, 0x20,
 0x53, 0x65, 0x70, 0x74, 0x65, 0x6d, 0x62, 0x65,
 0x72, 0x20, 0x31, 0x39, 0x39, 0x35, 0x00, 0x21,
 0xf9, 0x04, 0x01, 0x00, 0x00, 0x02, 0x00, 0x2c,
 0x00, 0x00, 0x00, 0x00, 0x14, 0x00, 0x16, 0x00,
 0x00, 0x03, 0x54, 0x28, 0xba, 0xdc, 0xfe, 0x30,
 0xca, 0x49, 0x59, 0xb9, 0xf8, 0xce, 0x12, 0xba,
 0xef, 0x45, 0xc4, 0x7d, 0x64, 0xa6, 0x29, 0xc5,
 0x40, 0x7a, 0x6a, 0x89, 0x06, 0x43, 0x2c, 0xc7,
 0x2b, 0x1c, 0x8e, 0xf5, 0x1a, 0x13, 0x57, 0x9e,
 0x0f, 0x3c, 0x9c, 0x8f, 0x05, 0xec, 0x0d, 0x49,
 0x45, 0xe1, 0x71, 0x67, 0x3c, 0xb2, 0x82, 0x4e,
 0x22, 0x34, 0xda, 0x49, 0x52, 0x61, 0x56, 0x98,
 0x56, 0xc5, 0xdd, 0xc2, 0x78, 0x82, 0xd4, 0x6c,
 0x3c, 0x26, 0x80, 0xc3, 0xe6, 0xb4, 0x7a, 0xcd,
 0x23, 0x2c, 0x4c, 0xf0, 0x8c, 0x3b, 0x01, 0x00,
 0x3b,
};

static const char zFileImage[] = {
 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x14, 0x00,
 0x16, 0x00, 0xc2, 0x00, 0x00, 0xff, 0xff, 0xff,
 0xcc, 0xff, 0xff, 0x99, 0x99, 0x99, 0x33, 0x33,
 0x33, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0xfe, 0x4e,
 0x54, 0x68, 0x69, 0x73, 0x20, 0x61, 0x72, 0x74,
 0x20, 0x69, 0x73, 0x20, 0x69, 0x6e, 0x20, 0x74,
 0x68, 0x65, 0x20, 0x70, 0x75, 0x62, 0x6c, 0x69,
 0x63, 0x20, 0x64, 0x6f, 0x6d, 0x61, 0x69, 0x6e,
 0x2e, 0x20, 0x4b, 0x65, 0x76, 0x69, 0x6e, 0x20,
 0x48, 0x75, 0x67, 0x68, 0x65, 0x73, 0x2c, 0x20,
 0x6b, 0x65, 0x76, 0x69, 0x6e, 0x68, 0x40, 0x65,
 0x69, 0x74, 0x2e, 0x63, 0x6f, 0x6d, 0x2c, 0x20,
 0x53, 0x65, 0x70, 0x74, 0x65, 0x6d, 0x62, 0x65,
 0x72, 0x20, 0x31, 0x39, 0x39, 0x35, 0x00, 0x21,
 0xf9, 0x04, 0x01, 0x00, 0x00, 0x01, 0x00, 0x2c,
 0x00, 0x00, 0x00, 0x00, 0x14, 0x00, 0x16, 0x00,
 0x00, 0x03, 0x58, 0x38, 0xba, 0xbc, 0xf1, 0x30,
 0x0c, 0x40, 0xab, 0x9d, 0x23, 0xbe, 0x69, 0x3b,
 0xcf, 0x11, 0xd7, 0x55, 0x22, 0xb8, 0x8d, 0xd7,
 0x05, 0x71, 0x44, 0xeb, 0x52, 0xc4, 0x10, 0xcf,
 0x27, 0x0a, 0xbb, 0x6e, 0x8d, 0xb7, 0x96, 0xe0,
 0x0b, 0x84, 0x9a, 0xad, 0xf2, 0x0b, 0x4a, 0x6e,
 0xbb, 0x17, 0x05, 0x28, 0x1c, 0x12, 0x8d, 0xac,
 0xa4, 0x12, 0xc0, 0x3c, 0x3a, 0x7b, 0x50, 0xa4,
 0xf4, 0xd9, 0xbc, 0x56, 0x45, 0xda, 0xe9, 0xf7,
 0x8a, 0xed, 0x6e, 0x97, 0x59, 0x32, 0xba, 0xeb,
 0xfc, 0x0e, 0x7e, 0xf0, 0xb8, 0x4f, 0x16, 0x91,
 0xda, 0x8d, 0x09, 0x00, 0x3b,
};

/*
** WEBPAGE: /ck.gif
*/
void image_ck(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zCkImage, sizeof(zCkImage));
  g.isConst = 1;
}

/*
** WEBPAGE: /dot.gif
*/
void image_dot(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zDotImage, sizeof(zDotImage));
  g.isConst = 1;
}

/*
** WEBPAGE: /x.gif
*/
void image_x(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zXImage, sizeof(zXImage));
  g.isConst = 1;
}

/*
** WEBPAGE: /dia.gif
*/
void image_dia(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zDiaImage, sizeof(zDiaImage));
  g.isConst = 1;
}

/*
** WEBPAGE: /backup.gif
*/
void image_backup(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zBackupImage, sizeof(zBackupImage));
  g.isConst = 1;
}
/*
** WEBPAGE: /dir.gif
*/
void image_dir(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zDirImage, sizeof(zDirImage));
  g.isConst = 1;
}
/*
** WEBPAGE: /file.gif
*/
void image_file(void){
  cgi_set_content_type("image/gif");
  cgi_append_content(zFileImage, sizeof(zFileImage));
  g.isConst = 1;
}
